# -*- coding: utf-8 -*-
__version__ = "0.2.2"

from pluggy import HookimplMarker
from napari.plugins.hook_specifications import LayerData, ReaderFunction
from typing import List, Optional
import mrc
from numpy import memmap

napari_hook_implementation = HookimplMarker("napari")


def dv_reader(path: str) -> List[LayerData]:
    mfile = mrc.Mrc(path)
    nWaves = mfile.header.NumWaves
    channel_axis = mfile.axisOrderStr().find("w") if nWaves > 1 else None
    dx = mfile.header.d[0]
    dz = mfile.header.d[2]
    metadata = {
        name: getattr(mfile.hdr, name)
        for name in mrc.mrc.mrcHdrNames
        if not name.startswith("_")
    }
    metadata = {
        k: v.tolist() if isinstance(metadata["mst"], memmap) else v
        for k, v in metadata.items()
    }
    if nWaves == 1:
        contrast_limits = list(mfile.header.mmm1[:2])
        name = f"{mfile.hdr.wave[0]} nm"
    else:
        contrast_limits = []
        name = []
        for c in range(nWaves):
            key = f"mmm{c+1}" if c == 0 else f"mm{c+1}"
            contrast_limits.append(list(getattr(mfile.header, key)[:2]))
            name.append(f"{mfile.hdr.wave[c]} nm")
    params = {
        "channel_axis": channel_axis,
        "scale": [dz / dx, 1, 1],
        "contrast_limits": contrast_limits,
        "name": name,
        "metadata": metadata,
    }
    return [(mfile.data, params)]


@napari_hook_implementation
def napari_get_reader(path: str) -> Optional[ReaderFunction]:
    if path.endswith((".dv", ".mrc")):
        return dv_reader



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding="utf-8").read()


setup(
    name="napari-dv",
    version="0.2.2",
    author="Talley Lambert",
    author_email="talley.lambert@gmail.com",
    maintainer="Talley Lambert",
    maintainer_email="talley.lambert@gmail.com",
    license="MIT",
    url="https://github.com/tlambert03/napari-dv",
    description="Deltavision/MRC file reader for napari",
    long_description=read("README.rst"),
    py_modules=["napari_dv"],
    python_requires=">=3.6",
    install_requires=["napari>=0.2.11", "mrc>=0.1.5", "pluggy>=0.13.1"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Testing",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
    ],
    entry_points={"napari.plugin": ["dv_reader = napari_dv"]},
)
